pub struct AsmError {
pub line_num: usize,
pub pos: Option<usize>,
pub inner_err: Option<Box<AsmError>>,
/* private fields */
}Expand description
The cause of a failure from assemble.
This includes the line number and column of the error, and the inner error, if any. However, to future-proof the assembler, the enum representing the actual error is private.
This type implements Display to get a user-level error message.
These error messages try to be as clear as possible and give hints about correct usage.
Fields
line_num: usizeLine number of the error
pos: Option<usize>Byte index of the error in the line (if relevant and available)
inner_err: Option<Box<AsmError>>Error which caused this error (if relevant)