pub enum State {
Uninitialized,
Running,
Terminated(i32),
Error(ExecError),
}Expand description
Current state of an emulator.
Variants
Uninitialized
The emulator has not been initialized with a program to run.
Running
The emulator is still running.
Terminated(i32)
The emulator terminated successfully with the given return code.
Error(ExecError)
The emulator terminated due to an error.