Everything needed to handle expression trees.
The important types are Expr, which represents an expression tree, and SymbolTable, which is the special collection type used for evaluation.
Structs
- Expr
- An expression.
- Symbol
Table - An appendonly map-like collection of defined symbols.
Enums
- Expr
Data - Holds the information needed to create an instance of
Expr. - OP
- The supported operations in an expr.
- Value
- Represents a value (leaf node) in an
Exprtree.
Constants
- FLOAT_
PRECISION - Number of precision bits to use for floating point values.
- INT_
PRECISION - Maximum number of significant bits to use for integer values.