pub enum Value {
Logical(bool),
Pointer(u64),
Character(char),
Integer(Integer),
Float(Float),
Binary(Vec<u8>),
}Expand description
Represents a value (leaf node) in an Expr tree.
The CSX64 assembler has strongly-typed value semantics (at assemble-time) based on rust.
For instance, attempting to use 0 (integer) in a boolean condition will cause an assemble error.
This enum differentiates all of the supported value types.
For users of this crate, you will only interact with this type in order to create instances of Expr.
Expr implements From<Value> for this purpose, and Value implements From<T> for many primitive types:
Integer:u*,i*Floating:f*Logical:boolCharacter:charBinary:Vec<u8>,&[u8],&str
Note that within a CSX64 assembly file, string literals are represented as a Binary value.
The assembler makes no distinction between arbitrary binary content and a string (regardless of encoding).
Variants