#[repr(align(64))]pub struct ZMMRegister(pub [u8; 64]);Expand description
Represents a 512-bit ZMM (vector) register.
Values are held as an array of 64 bytes, which is suitably aligned for use in any simd operations. Multi-byte values must be stored little-endian to facilitate the correct index behavior. The provided element accessors automatically do this, but care should be taken if accessing the data directly (e.g. for simd operations).
Tuple Fields
0: [u8; 64]Implementations
Sourceimpl ZMMRegister
impl ZMMRegister
pub fn get_u8(&self, index: usize) -> u8
pub fn set_u8(&mut self, index: usize, value: u8)
pub fn get_u16(&self, index: usize) -> u16
pub fn set_u16(&mut self, index: usize, value: u16)
pub fn get_u32(&self, index: usize) -> u32
pub fn set_u32(&mut self, index: usize, value: u32)
pub fn get_u64(&self, index: usize) -> u64
pub fn set_u64(&mut self, index: usize, value: u64)
pub fn get_i64(&self, index: usize) -> i64
pub fn set_i64(&mut self, index: usize, value: i64)
pub fn get_i32(&self, index: usize) -> i32
pub fn set_i32(&mut self, index: usize, value: i32)
pub fn get_i16(&self, index: usize) -> i16
pub fn set_i16(&mut self, index: usize, value: i16)
pub fn get_i8(&self, index: usize) -> i8
pub fn set_i8(&mut self, index: usize, value: i8)
pub fn get_f64(&self, index: usize) -> f64
pub fn set_f64(&mut self, index: usize, value: f64)
pub fn get_f32(&self, index: usize) -> f32
pub fn set_f32(&mut self, index: usize, value: f32)